# -*- coding: utf-8 -*-


from jinja2.exceptions import FilterArgumentError
from jinja2._compat import string_types


def sort_dict(value, case_sensitive=False, by='key', reverse=False, index=0):
    """
    字典排序
    :param value: 字典对象
    :param case_sensitive: 是否大小写敏感
    :param by: 排序对象
    :param reverse: 排序方式（正序：True、倒序：False）
    :param index: 索引号（此处针对 value 为 list 情况下可根据 list 的某一 index 排序）
    :return:
    """
    if by == 'key':
        pos = 0
    elif by == 'value':
        pos = 1
    else:
        raise FilterArgumentError('You can only sort by either "key" or "value"')
    def sort_func(item):
        value = item[pos]
        if index:
            try:
                value = value[index]
            except:
                pass
        if isinstance(value, string_types) and not case_sensitive:
            value = value.lower()
        return value

    return sorted(value.items(), key=sort_func, reverse=reverse)



# -*- coding: utf-8 -*-

from setuptools import find_packages, setup


with open('README.md', 'r') as fh:
    readme = fh.read()

setup(
    name='Jinja2-Ext',
    version='0.1',
    url='https://github.com/zengqiu/jinja2-ext',
    license='MIT',
    author='zengqiu',
    author_email='zengqiu@qq.com',
    description='Extensions of Jinja2',
    long_description=readme,
    long_description_content_type='text/markdown',
    packages=find_packages(),
    platforms='any',
    install_requires=[
        'Jinja2',
    ],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ]
)